@@ -15,11 +15,15 @@
 #include <liqbase/liqcell_easyhandler.h>
 
 
+int playground_editable=0;
+
+
 
 liqcell *liqbase_playground_root=NULL;
 
 
 
+	static int playground_item_mouse(liqcell *self, liqcellmouseeventargs *args, liqcell *playground);
 	static int playground_item_click(liqcell *self, liqcellclickeventargs *args, liqcell *playground);
     static int playground_item_dirty(liqcell *self, liqcelleventargs *args, liqcell *playground);
 
@@ -49,10 +53,90 @@ liqcell *liqbase_playground_root=NULL;
 			liqcell_propseti(  item,    "lockaspect",1);
 			liqcell_setcontent(item,    newx);
 			liqcell_handleradd_withcontext(item,    "click",   playground_item_click,desktopmanage );
-			liqcell_child_append( body, item );
+			liqcell_handleradd_withcontext(item,    "mouse",   playground_item_mouse,desktopmanage );
+			liqcell_child_insertsortedbyname( body, item , 1);
 			return item;
 			
 		}
+
+
+
+
+
+
+
+
+
+        extern char * liqtwitter_message;
+
+
+
+        static int playground_send_tweet(liqcell *button, liqcellclickeventargs *args, liqcell *playground)
+        {
+            liqcell *search = liqcell_child_lookup(playground,"search");
+            liqapp_log("send a tweet :)");
+            liqtwitter_message = liqcell_getcaption(search);
+            
+            liqcell * progress = liqcell_quickcreatevis("liqbase-playground.liqtwitter_sendprogress","liqbase-playground.liqtwitter_sendprogress",0,0,-1,-1);
+            
+            if(progress)
+            {
+                liqcell_easyrun(progress);
+                int sentok = liqcell_propgeti(progress,"sentok",0);
+                liqcell_release(progress);
+                
+                if(!sentok)
+                {
+                    //return 0;
+                }
+                
+                if(sentok)
+                {
+                    liqcell_setcaption(search,"");
+                }
+            }            
+            return 0;
+        }
+
+
+
+        static int playground_send_google(liqcell *button, liqcellclickeventargs *args, liqcell *playground)
+        {
+            liqapp_log("send to google :)");
+        }
+
+
+
+
+        static int playground_send_console(liqcell *button, liqcellclickeventargs *args, liqcell *playground)
+        {
+            liqapp_log("run a sh command :)");
+        }
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -109,6 +193,9 @@ int liqbase_playground_refresh_desktop_contents()
 
 
     //liqbase_playground_root
+    
+    
+    liqapp_log("liqbase_playground_refresh_desktop_contents: '%s'",listall?listall:"[nothing_curious]");
 
     
     char tokbuf[2048]={0};
@@ -119,11 +206,18 @@ int liqbase_playground_refresh_desktop_contents()
     // first, run around and remove stuff we no longer need
     liqcell *c = liqcell_getlinkchild_visual(body);
     
-    // skip the first item...
-    if(c)c = liqcell_getlinknext_visual(c);
+   // // skip the first item...
+   // if(c)c = liqcell_getlinknext_visual(c);
     
     while(c)
     {
+        
+            if( (strcasecmp(c->name,"desktopmanage"   )==0) ||
+                (strcasecmp(c->name,"_searchinprogress")==0) )
+            {
+                c=liqcell_getlinknext_visual(c);
+                continue;
+            }
 
             int isok = 0;
             // loop around the tokens
@@ -296,7 +390,12 @@ int liqcell_filter_run(liqcell *c,char *searchterm)
 		liqcell *body = liqcell_child_lookup(playground,"body");
 		char *searchterm = liqcell_getcaption(self);
 		
-        liqcell *searchinprogress = liqcell_child_lookup(body,"searchinprogress");
+        liqcell *searchinprogress = liqcell_child_lookup(body,"_searchinprogress");
+        if(!searchinprogress)
+        {
+            liqapp_log("search: missing search progress");
+            return 0;
+        }
         
 		liqcell *c = liqcell_getlinkchild_visual(body);
 		while(c)
@@ -304,6 +403,8 @@ int liqcell_filter_run(liqcell *c,char *searchterm)
 			liqcell_filter_run(c,searchterm);
 			c=liqcell_getlinknext_visual(c);
 		}
+        
+        liqapp_log("search: sorting progress");
 
         liqcell_setvisible(searchinprogress,0);
             
@@ -322,12 +423,17 @@ int liqcell_filter_run(liqcell *c,char *searchterm)
             liqcell_setvisible(searchinprogress,0);
         else
             liqcell_setvisible(searchinprogress,1);
+            
+        liqapp_log("search: sorting body");
+            
         
 		//liqcell_setrect(body,   0,40,playground->w,playground->h-40);
 		liqcell_setrect(body,   0,0,playground->w,playground->h);
 		liqcell_child_arrange_easytile( body );
 		//liqcell_child_arrange_makegrid_fly(body,3,3);
 		
+        liqcell_child_arrange_easytile(searchinprogress);
+        
 		liqcell_propseti(self,"arrangecomplete",0);
 		
 		//liqcell_setpos(body,0,40);
@@ -353,7 +459,22 @@ int liqcell_filter_run(liqcell *c,char *searchterm)
 //#####################################################################
 //#####################################################################
 	
-	
+	static int playground_item_mouse(liqcell *self, liqcellmouseeventargs *args, liqcell *playground)
+	{
+		//args->newdialogtoopen = liqcell_getcontent( self );
+        
+        if(!playground_editable) return 1;
+
+		liqcell_adjustpos((self),args->mdx,args->mdy);
+
+		int liqcell_child_arrange_nooverlap(liqcell *self,liqcell *currentselection);
+		int liqcell_child_arrange_gapfill(liqcell *self,liqcell *currentselection);
+
+		liqcell_child_arrange_nooverlap( liqcell_getlinkparent(self), self );
+
+    
+		return 1;
+	}	
 	static int playground_item_click(liqcell *self, liqcellclickeventargs *args, liqcell *playground)
 	{
 		args->newdialogtoopen = liqcell_getcontent( self );
@@ -523,6 +644,9 @@ liqcell *playground_create()
 
 	if(self)
 	{
+
+
+
 	/*	//############################# title:label
 		liqcell *title = liqcell_quickcreatevis("title", "label", 0,0, 400, 40);
 		liqcell_setfont(	title, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
@@ -550,8 +674,15 @@ liqcell *playground_create()
 	
 		liqcell *body = liqcell_quickcreatevis("body",NULL,0 ,0,   self->w,self->h);
 
+
+
+        liqcell_propseti(body,"liqcell_child_arrange_nooverlap_minimumw",80);
+        liqcell_propseti(body,"liqcell_child_arrange_nooverlap_minimumh",48);
+
+
+
 		//############################# searchinprogress:label
-		liqcell *searchinprogress = liqcell_quickcreatevis("searchinprogress", NULL, 600, 440, 200, 60);
+		liqcell *searchinprogress = liqcell_quickcreatevis("_searchinprogress", NULL, 600, 440, 200, 60);
 		liqcell_setfont(	searchinprogress, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (35), 0) );
 		liqcell_setcaption(searchinprogress, "searching:" );
 		liqcell_propsets(  searchinprogress, "textcolor",   "rgb(0,255,0)" );
@@ -563,13 +694,49 @@ liqcell *playground_create()
         liqcell_setvisible(searchinprogress,0);
  
  
-
-
+ 
+ 
  
 
  
+ 
+		liqcell *addsearchkind(char *title,char *imgfilename,void *clickhandler)
+		{
+            
+            
+            
+            
+			
+			//liqcell *item = newx;
+			
+			liqcell *item = liqcell_quickcreatevis(title,"item",0,0,100,100);
+            
+            liqcell_setimage(  item ,  liqimage_cache_getfile( imgfilename,0,0,1) );
+			liqcell_propseti(  item,    "lockaspect",1);
+			
+			liqcell_handleradd_withcontext(item,    "click",   clickhandler ,self );
+			liqcell_child_append( searchinprogress, item );
+			return item;
+			
+		}
+        
+        addsearchkind( "google","/usr/share/liqbase/media/searchimg/google.jpg"   , playground_send_google );
+        addsearchkind( "console","/usr/share/liqbase/media/searchimg/console.jpg" , playground_send_console );
+        
+        
+ 
 
 
+        liqapp_log("liqtwit: looking up twituser credentials");
+        char *twitname = liqapp_pref_getvalue("twitname");
+        char *twitpass = liqapp_pref_getvalue("twitpass");
+        if(twitname && *twitname  && twitpass && *twitpass)
+        {
+            // ok
+            addsearchkind( "twitter","/usr/share/liqbase/media/searchimg/twitter.png" , playground_send_tweet );
+        } 
+
+        liqcell_child_arrange_easytile(searchinprogress);
 
 		//liqcell_handleradd(body,    "mouse",   liqcell_easyhandler_kinetic_mouse );
 		liqcell_child_insert( self, body );
@@ -641,7 +808,7 @@ liqcell *playground_create()
                 addone(self,body, "liqflow");
             }
             
-            addone(self,body, "floatmap");
+            //addone(self,body, "floatmap");
             
             addone(self,body, "onedotzero");
            // addone(self,body, "liqpostcard");
